*     JLdL 02Jan21.
*     
*     Copyright (C) 2020-2021 by Jorge L. deLyra <delyra@lmail.if.usp.br>.
*     This program can be copied and/or distributed freely under the
*     GPL license; see the terms and conditions in the files within
*     the sub-directory doc/ of this source directory.
*     
*     A function to return the value of the cubic polynomial on \xi,
*     shown in Equation (78) of the paper; the variables passed are:
*     
*     xi2_var_loc : the outer shell radius \xi_{2};
*     xim_var_loc : the Schwarzschild radius \xi_{M};
*     xi_var_loc  : the radius variable \xi.
*     
*     This routine uses the following additional local
*     double-precision temporary variable:
*     
*     polynomial_loc : local temporary for the polynomial.
*     
*     The polynomial is given by (LaTeX codes):
*     
*     \xi_{2}^{3} - \xi^{3} + 3 ( \xi - \xi_{M} )
*     
*     Complex formulas contained in this routine: the cubic polynomial.
*     
      FUNCTION POLYNOMIAL_FUN
     *     (xi2_var_loc
     *     ,xim_var_loc
     *     ,xi_var_loc)
*     
*     Double precision everything; due to the gfortran compiler option
*     -fdefault-real-8, which is in use in the Makefile, this is actually
*     quadruple precision, in the traditional sense of the term, that is,
*     it is actually real*16 (128-bit real data).
      implicit double precision (a-h,o-z)
*     
*     Calculate the function.
      polynomial_loc=
     *     xi2_var_loc**3-xi_var_loc**3
      polynomial_loc=polynomial_loc
     *     +3.0d0*(xi_var_loc-xim_var_loc)
*     
*     Pass the function.
      polynomial_fun=polynomial_loc
*     
      return
*     
      END
